from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class STTComponentRequest(_message.Message):
    __slots__ = ("run_id", "audio")
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    AUDIO_FIELD_NUMBER: _ClassVar[int]
    run_id: str
    audio: bytes
    def __init__(self, run_id: _Optional[str] = ..., audio: _Optional[bytes] = ...) -> None: ...

class STTComponentResponse(_message.Message):
    __slots__ = ("run_id", "content_chunk")
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    CONTENT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    run_id: str
    content_chunk: str
    def __init__(self, run_id: _Optional[str] = ..., content_chunk: _Optional[str] = ...) -> None: ...

class T2TComponentRequest(_message.Message):
    __slots__ = ("run_id", "system_input", "user_input")
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_INPUT_FIELD_NUMBER: _ClassVar[int]
    USER_INPUT_FIELD_NUMBER: _ClassVar[int]
    run_id: str
    system_input: str
    user_input: str
    def __init__(self, run_id: _Optional[str] = ..., system_input: _Optional[str] = ..., user_input: _Optional[str] = ...) -> None: ...

class T2TComponentResponse(_message.Message):
    __slots__ = ("run_id", "content_chunk")
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    CONTENT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    run_id: str
    content_chunk: str
    def __init__(self, run_id: _Optional[str] = ..., content_chunk: _Optional[str] = ...) -> None: ...

class TTSGComponentRequest(_message.Message):
    __slots__ = ("run_id", "content")
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    run_id: str
    content: str
    def __init__(self, run_id: _Optional[str] = ..., content: _Optional[str] = ...) -> None: ...

class TTSGComponentResponse(_message.Message):
    __slots__ = ("run_id", "audio_chunk")
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    AUDIO_CHUNK_FIELD_NUMBER: _ClassVar[int]
    run_id: str
    audio_chunk: bytes
    def __init__(self, run_id: _Optional[str] = ..., audio_chunk: _Optional[bytes] = ...) -> None: ...

class TTSCComponentRequest(_message.Message):
    __slots__ = ("run_id", "audio")
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    AUDIO_FIELD_NUMBER: _ClassVar[int]
    run_id: str
    audio: bytes
    def __init__(self, run_id: _Optional[str] = ..., audio: _Optional[bytes] = ...) -> None: ...

class TTSCComponentResponse(_message.Message):
    __slots__ = ("run_id", "audio_chunk")
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    AUDIO_CHUNK_FIELD_NUMBER: _ClassVar[int]
    run_id: str
    audio_chunk: bytes
    def __init__(self, run_id: _Optional[str] = ..., audio_chunk: _Optional[bytes] = ...) -> None: ...



from .grpc.jaisongrpc_pb2 import STTComponentRequest, STTComponentResponse, T2TComponentRequest, T2TComponentResponse, TTSGComponentRequest, TTSGComponentResponse, TTSCComponentRequest, TTSCComponentResponse


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

import jaisongrpc_pb2 as jaisongrpc__pb2

GRPC_GENERATED_VERSION = '1.68.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in jaisongrpc_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class STTComponentStreamerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.invoke = channel.unary_stream(
                '/jaisongrpc.STTComponentStreamer/invoke',
                request_serializer=jaisongrpc__pb2.STTComponentRequest.SerializeToString,
                response_deserializer=jaisongrpc__pb2.STTComponentResponse.FromString,
                _registered_method=True)


class STTComponentStreamerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def invoke(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_STTComponentStreamerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'invoke': grpc.unary_stream_rpc_method_handler(
                    servicer.invoke,
                    request_deserializer=jaisongrpc__pb2.STTComponentRequest.FromString,
                    response_serializer=jaisongrpc__pb2.STTComponentResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'jaisongrpc.STTComponentStreamer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('jaisongrpc.STTComponentStreamer', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class STTComponentStreamer(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def invoke(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/jaisongrpc.STTComponentStreamer/invoke',
            jaisongrpc__pb2.STTComponentRequest.SerializeToString,
            jaisongrpc__pb2.STTComponentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class T2TComponentStreamerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.invoke = channel.unary_stream(
                '/jaisongrpc.T2TComponentStreamer/invoke',
                request_serializer=jaisongrpc__pb2.T2TComponentRequest.SerializeToString,
                response_deserializer=jaisongrpc__pb2.T2TComponentResponse.FromString,
                _registered_method=True)


class T2TComponentStreamerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def invoke(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_T2TComponentStreamerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'invoke': grpc.unary_stream_rpc_method_handler(
                    servicer.invoke,
                    request_deserializer=jaisongrpc__pb2.T2TComponentRequest.FromString,
                    response_serializer=jaisongrpc__pb2.T2TComponentResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'jaisongrpc.T2TComponentStreamer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('jaisongrpc.T2TComponentStreamer', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class T2TComponentStreamer(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def invoke(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/jaisongrpc.T2TComponentStreamer/invoke',
            jaisongrpc__pb2.T2TComponentRequest.SerializeToString,
            jaisongrpc__pb2.T2TComponentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class TTSGComponentStreamerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.invoke = channel.unary_stream(
                '/jaisongrpc.TTSGComponentStreamer/invoke',
                request_serializer=jaisongrpc__pb2.TTSGComponentRequest.SerializeToString,
                response_deserializer=jaisongrpc__pb2.TTSGComponentResponse.FromString,
                _registered_method=True)


class TTSGComponentStreamerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def invoke(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TTSGComponentStreamerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'invoke': grpc.unary_stream_rpc_method_handler(
                    servicer.invoke,
                    request_deserializer=jaisongrpc__pb2.TTSGComponentRequest.FromString,
                    response_serializer=jaisongrpc__pb2.TTSGComponentResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'jaisongrpc.TTSGComponentStreamer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('jaisongrpc.TTSGComponentStreamer', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TTSGComponentStreamer(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def invoke(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/jaisongrpc.TTSGComponentStreamer/invoke',
            jaisongrpc__pb2.TTSGComponentRequest.SerializeToString,
            jaisongrpc__pb2.TTSGComponentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class TTSCComponentStreamerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.invoke = channel.unary_stream(
                '/jaisongrpc.TTSCComponentStreamer/invoke',
                request_serializer=jaisongrpc__pb2.TTSCComponentRequest.SerializeToString,
                response_deserializer=jaisongrpc__pb2.TTSCComponentResponse.FromString,
                _registered_method=True)


class TTSCComponentStreamerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def invoke(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TTSCComponentStreamerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'invoke': grpc.unary_stream_rpc_method_handler(
                    servicer.invoke,
                    request_deserializer=jaisongrpc__pb2.TTSCComponentRequest.FromString,
                    response_serializer=jaisongrpc__pb2.TTSCComponentResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'jaisongrpc.TTSCComponentStreamer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('jaisongrpc.TTSCComponentStreamer', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TTSCComponentStreamer(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def invoke(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/jaisongrpc.TTSCComponentStreamer/invoke',
            jaisongrpc__pb2.TTSCComponentRequest.SerializeToString,
            jaisongrpc__pb2.TTSCComponentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: jaisongrpc.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'jaisongrpc.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10jaisongrpc.proto\x12\njaisongrpc\"4\n\x13STTComponentRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\r\n\x05\x61udio\x18\x02 \x01(\x0c\"=\n\x14STTComponentResponse\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x15\n\rcontent_chunk\x18\x02 \x01(\t\"O\n\x13T2TComponentRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x14\n\x0csystem_input\x18\x02 \x01(\t\x12\x12\n\nuser_input\x18\x03 \x01(\t\"=\n\x14T2TComponentResponse\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x15\n\rcontent_chunk\x18\x02 \x01(\t\"7\n\x14TTSGComponentRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"<\n\x15TTSGComponentResponse\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x13\n\x0b\x61udio_chunk\x18\x02 \x01(\x0c\"5\n\x14TTSCComponentRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\r\n\x05\x61udio\x18\x02 \x01(\x0c\"<\n\x15TTSCComponentResponse\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x13\n\x0b\x61udio_chunk\x18\x02 \x01(\x0c\x32g\n\x14STTComponentStreamer\x12O\n\x06invoke\x12\x1f.jaisongrpc.STTComponentRequest\x1a .jaisongrpc.STTComponentResponse\"\x00\x30\x01\x32g\n\x14T2TComponentStreamer\x12O\n\x06invoke\x12\x1f.jaisongrpc.T2TComponentRequest\x1a .jaisongrpc.T2TComponentResponse\"\x00\x30\x01\x32j\n\x15TTSGComponentStreamer\x12Q\n\x06invoke\x12 .jaisongrpc.TTSGComponentRequest\x1a!.jaisongrpc.TTSGComponentResponse\"\x00\x30\x01\x32j\n\x15TTSCComponentStreamer\x12Q\n\x06invoke\x12 .jaisongrpc.TTSCComponentRequest\x1a!.jaisongrpc.TTSCComponentResponse\"\x00\x30\x01\x42\x1c\n\rex.jaisongrpc\xa2\x02\njaisongrpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'jaisongrpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\rex.jaisongrpc\242\002\njaisongrpc'
  _globals['_STTCOMPONENTREQUEST']._serialized_start=32
  _globals['_STTCOMPONENTREQUEST']._serialized_end=84
  _globals['_STTCOMPONENTRESPONSE']._serialized_start=86
  _globals['_STTCOMPONENTRESPONSE']._serialized_end=147
  _globals['_T2TCOMPONENTREQUEST']._serialized_start=149
  _globals['_T2TCOMPONENTREQUEST']._serialized_end=228
  _globals['_T2TCOMPONENTRESPONSE']._serialized_start=230
  _globals['_T2TCOMPONENTRESPONSE']._serialized_end=291
  _globals['_TTSGCOMPONENTREQUEST']._serialized_start=293
  _globals['_TTSGCOMPONENTREQUEST']._serialized_end=348
  _globals['_TTSGCOMPONENTRESPONSE']._serialized_start=350
  _globals['_TTSGCOMPONENTRESPONSE']._serialized_end=410
  _globals['_TTSCCOMPONENTREQUEST']._serialized_start=412
  _globals['_TTSCCOMPONENTREQUEST']._serialized_end=465
  _globals['_TTSCCOMPONENTRESPONSE']._serialized_start=467
  _globals['_TTSCCOMPONENTRESPONSE']._serialized_end=527
  _globals['_STTCOMPONENTSTREAMER']._serialized_start=529
  _globals['_STTCOMPONENTSTREAMER']._serialized_end=632
  _globals['_T2TCOMPONENTSTREAMER']._serialized_start=634
  _globals['_T2TCOMPONENTSTREAMER']._serialized_end=737
  _globals['_TTSGCOMPONENTSTREAMER']._serialized_start=739
  _globals['_TTSGCOMPONENTSTREAMER']._serialized_end=845
  _globals['_TTSCCOMPONENTSTREAMER']._serialized_start=847
  _globals['_TTSCCOMPONENTSTREAMER']._serialized_end=953
# @@protoc_insertion_point(module_scope)



from .grpc.jaisongrpc_pb2_grpc import add_STTComponentStreamerServicer_to_server, add_T2TComponentStreamerServicer_to_server, add_TTSGComponentStreamerServicer_to_server, add_TTSCComponentStreamerServicer_to_server
from .grpc.jaisongrpc_pb2_grpc import STTComponentStreamerServicer, T2TComponentStreamerServicer, TTSGComponentStreamerServicer, TTSCComponentStreamerServicer